@@ -56,6 +56,8 @@ class MongoAggregation(list):
         self.pipeline.append({'$count': 'count'})
 
     def match(self, *args, **kwargs):
+        if not args and not kwargs:
+            return self
         if args:
             for arg in args:
                 self.pipeline.append({
@@ -103,6 +105,9 @@ class MongoAggregation(list):
         self._add_to_actual_fields(field, ignore_if_theres_children=True)
         return self
 
+    def order_by(self, *args, **kwargs):
+        return self.sort(*args, **kwargs)
+
     def sort(self, *args, **kwargs):
         def _prepare_str_order_rule(order_rule):
             if not isinstance(order_rule, six.string_types):
